/**
 * OW2 Util
 * Copyright (C) 2008 SERLI
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FileArchiveImpl.java
 * --------------------------------------------------------------------------
 */

package org.ow2.util.archive.impl;

import static org.ow2.util.url.URLUtils.fileToURL2;

import java.io.File;
import java.net.URL;
import java.util.Iterator;

import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.archive.api.IArchiveMetadata;
import org.ow2.util.archive.api.IFileArchive;
import org.ow2.util.url.URLUtilsException;

/**
 * An implementation for the IFileArchive class.
 * @author mleduque
 */
public class FileArchiveImpl implements IFileArchive {

    /**
     * The file of the archive.
     */
    private File file = null;

    /**
     * Constructor with no arguments.
     */
    public FileArchiveImpl() {
    }

    /**
     * Constructs a file archive wit the given file.
     * @param file the given file
     */
    public FileArchiveImpl(final File file) {
        this.file = file;
    }

    /**
     * {@inheritDoc}
     */
    public void setFile(final File file) {
        this.file = file;
    }

    /**
     * {@inheritDoc}
     */
    public File getFile() {
        return this.file;
    }

    /**
     * {@inheritDoc}
     */
    public boolean close() {
        return true;
    }

    /**
     * {@inheritDoc}
     */
    public IArchiveMetadata getMetadata() {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return file.getPath();
    }

    /**
     * {@inheritDoc}
     */
    public URL getResource(final String resourceName) throws ArchiveException {
        throw new ArchiveException("No resources inside this file");
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<URL> getResources() throws ArchiveException {
        throw new ArchiveException("No resources inside this file");
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<URL> getResources(final String resourceName)
            throws ArchiveException {
        throw new ArchiveException("No resources inside this file");
    }

    /**
     * {@inheritDoc}
     */
    public URL getURL() throws ArchiveException {
        try {
            return fileToURL2(file);
        } catch (URLUtilsException e) {
            throw new IllegalStateException("Invalid url", e);
        }
    }

    /**
     * {@inheritDoc}
     */
    public Iterator<String> getEntries() throws ArchiveException {
        return null;
    }

    /**
     * @return a string representation of the object.
     */
    @Override
    public String toString() {
        return getName();
    }
}
